'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});
exports.toList = toList;
exports.findDocById = findDocById;
exports.findDoc = findDoc;
exports.deleteDocFromList = deleteDocFromList;
exports.invalidateFolders = invalidateFolders;
exports.setDocInList = setDocInList;
exports.createActionType = createActionType;
exports.markDocumentDeleted = markDocumentDeleted;
exports.createDetailLink = createDetailLink;

var _immutable = require('immutable');

/*
 * Returns immutablejs `List` from payload
 */

function toList(payload) {
  return (0, _immutable.List)(payload.rows.map(function (row) {
    return (0, _immutable.fromJS)(row.doc);
  }));
}

/**
 * findDocById
 *
 * @param {immutable.List} list
 * @param {string} docId
 * @returns {number}
 */

function findDocById(list, docId) {
  return list.findIndex(function (item) {
    return item.get('_id') === docId;
  });
}

function findDoc(list, doc) {
  return findDocById(list, doc.get('_id'));
}

function deleteDocFromList(list, doc) {
  var index = findDoc(list, doc);
  if (index === -1) {
    return list;
  }
  return list['delete'](index);
}

function invalidateFolders(state) {
  return state.set('folders', (0, _immutable.Map)());
}

/*
 * Replaces document `doc` in a given `list`
 *
 * Return original `list` if `doc` is not found
 */

function setDocInList(list, doc) {
  var index = findDoc(list, doc);
  if (index === -1) {
    return list;
  }
  return list.set(index, doc);
}

/**
 * Returns object from state
 *
 * @param {object} state
 * @param {string} mountPoint
 * @param {object} docId
 * @returns {immutable.Map}
 */
var getObjectFromState = function getObjectFromState(state, mountPoint, docId) {
  return state[mountPoint].get('documents').get(docId);
};

exports.getObjectFromState = getObjectFromState;
/**
 * createActionType
 *
 * @param {string} prefix
 * @param {string} action
 * @param {string} type
 * @returns {string}
 */

function createActionType(prefix, action, type) {
  return 'POUCHDB_' + prefix + '_' + action + '_' + type;
}

/**
 * markDocumentDeleted
 *
 * @param {immutable.Map} state
 * @param {string} docId
 * @returns {immutable.Map} new state
 */

function markDocumentDeleted(state, docId) {
  if (state.hasIn(['documents', docId])) {
    return state;
  }
  return state.setIn(['documents', docId, '_deleted'], true);
}

/**
 * createDetailLink
 *
 * @param urlPrefix
 * @param docId
 * @returns {string}
 */

function createDetailLink(urlPrefix, docId) {
  return urlPrefix + '/' + docId + '/';
}